==> estateplat-common-1.2.4-20220621.084244-1048-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/QlfQlGzdjNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbDateAdapter;
import cn.gtmap.estateplat.utils.JaxbNotNullDateAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

@XmlRootElement(name = "QLF_QL_GZDJ")
@Table(name = "QLF_QL_GZDJ")
public class QlfQlGzdjNew implements Serializable, AccessData {
    final static String ysdm = "6005050000";
    private String bdcdyh;
    private String ywh;
    private String ssywh;
    private String bdcqzh;
    private String bdczmh;
    private String gzdjlx;
    private String gzyj;
    private String gzgt;
    private String gznr;
    private String qxdm;
    private String djjg;
    private String dbr;
    private Date djsj;
    private String fj;
    private String qszt;
    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "BDCDYH")
    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }
    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }
    @XmlAttribute(name = "SSYWH")
    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }
    @XmlAttribute(name = "BDCQZH")
    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }
    @XmlAttribute(name = "BDCZMH")
    public String getBdczmh() {
        return bdczmh;
    }

    public void setBdczmh(String bdczmh) {
        this.bdczmh = bdczmh;
    }
    @XmlAttribute(name = "GZDJLX")
    public String getGzdjlx() {
        return gzdjlx;
    }

    public void setGzdjlx(String gzdjlx) {
        this.gzdjlx = gzdjlx;
    }
    @XmlAttribute(name = "GZYJ")
    public String getGzyj() {
        return gzyj;
    }

    public void setGzyj(String gzyj) {
        this.gzyj = gzyj;
    }
    @XmlAttribute(name = "GZGT")
    public String getGzgt() {
        return gzgt;
    }

    public void setGzgt(String gzgt) {
        this.gzgt = gzgt;
    }
    @XmlAttribute(name = "GZNR")
    public String getGznr() {
        return gznr;
    }

    public void setGznr(String gznr) {
        this.gznr = gznr;
    }
    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
    @XmlAttribute(name = "DJJG")
    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }
    @XmlAttribute(name = "DBR")
    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }
    @XmlAttribute(name = "DJSJ")
    @XmlJavaTypeAdapter(JaxbNotNullDateAdapter.class)
    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }
    @XmlAttribute(name = "FJ")
    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }
    @XmlAttribute(name = "QSZT")
    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }
}

==> estateplat-common-1.2.4-20220809.095945-1080-sources.jar: cn/gtmap/estateplat/model/exchange/national/newStandard/QlfQlGzdjNew.java <==
package cn.gtmap.estateplat.model.exchange.national.newStandard;

import cn.gtmap.estateplat.model.exchange.national.AccessData;
import cn.gtmap.estateplat.utils.JaxbDateAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import java.io.Serializable;
import java.util.Date;

@XmlRootElement(name = "QLF_QL_GZDJ")
@Table(name = "QLF_QL_GZDJ")
public class QlfQlGzdjNew implements Serializable, AccessData {
    final static String ysdm = "6005050000";
    private String bdcdyh;
    private String ywh;
    private String ssywh;
    private String bdcqzh;
    private String bdczmh;
    private String gzdjlx;
    private String gzyj;
    private String gzgt;
    private String gznr;
    private String qxdm;
    private String djjg;
    private String dbr;
    private Date djsj;
    private String fj;
    private String qszt;
    @XmlAttribute(name = "YSDM")
    public String getYsdm() {
        return ysdm;
    }

    @XmlAttribute(name = "BDCDYH")
    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }
    @XmlAttribute(name = "YWH")
    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }
    @XmlAttribute(name = "SSYWH")
    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }
    @XmlAttribute(name = "BDCQZH")
    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }
    @XmlAttribute(name = "BDCZMH")
    public String getBdczmh() {
        return bdczmh;
    }

    public void setBdczmh(String bdczmh) {
        this.bdczmh = bdczmh;
    }
    @XmlAttribute(name = "GZDJLX")
    public String getGzdjlx() {
        return gzdjlx;
    }

    public void setGzdjlx(String gzdjlx) {
        this.gzdjlx = gzdjlx;
    }
    @XmlAttribute(name = "GZYJ")
    public String getGzyj() {
        return gzyj;
    }

    public void setGzyj(String gzyj) {
        this.gzyj = gzyj;
    }
    @XmlAttribute(name = "GZGT")
    public String getGzgt() {
        return gzgt;
    }

    public void setGzgt(String gzgt) {
        this.gzgt = gzgt;
    }
    @XmlAttribute(name = "GZNR")
    public String getGznr() {
        return gznr;
    }

    public void setGznr(String gznr) {
        this.gznr = gznr;
    }
    @XmlAttribute(name = "QXDM")
    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
    @XmlAttribute(name = "DJJG")
    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }
    @XmlAttribute(name = "DBR")
    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }
    @XmlAttribute(name = "DJSJ")
    @XmlJavaTypeAdapter(JaxbDateAdapter.class)
    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }
    @XmlAttribute(name = "FJ")
    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }
    @XmlAttribute(name = "QSZT")
    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }
}
